/*
	TuxPuck - aiplayers.cpp
	Copyright (C) 2001 Jacob Kroon

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

	Jacob Kroon - d00jkr@efd.lth.se
*/

/* includes */
#include <stdlib.h>
#include "video.h"
#include "aiplayers.h"

/* externals */
extern unsigned char tux_tga[];
extern unsigned char tux_blink_spr[];
extern unsigned char cartman_tga[];
extern unsigned char cartman_unhappy_spr[];
extern unsigned char cartman_loosegame_spr[];
extern unsigned char cartman_kickass_wav[];
extern unsigned char cartman_soab_wav[];

/* TuxPlayer implemention */
TuxPlayer::TuxPlayer(Pad * pad, Puck * puck):AIPlayer(pad, puck, "Tux")
{
  _sdlTux = loadTga(tux_tga, NULL);
  _sprBlink = new Sprite(tux_blink_spr, NULL);
  _sprBlink->setPosition(292, 47);
  _speed = 4.0;
  _hitPower = 4.0;
}

TuxPlayer::~TuxPlayer()
{
  SDL_FreeSurface(_sdlTux);
  delete(_sprBlink);
}

void TuxPlayer::setState(Uint8 state)
{
  _state = state;
}

void TuxPlayer::blit(void)
{
  static SDL_Rect rect =
    { 320 - _sdlTux->w / 2, (Sint16) A2 - _sdlTux->h, 0, 0 };
  Video::instance()->blit(_sdlTux, &rect);
}

Uint8 TuxPlayer::reblit(Uint32 time)
{
  switch (_state)
    {
    case PLAYER_STATE_WIN_POINT:
    case PLAYER_STATE_LOOSE_POINT:
      _sprBlink->blit();
      if (_sprBlink->update(time) == 0)
	{
	  _sprBlink->erase();
	  _state = PLAYER_STATE_IDLE;
	}
      break;
    case PLAYER_STATE_WIN_GAME:
    case PLAYER_STATE_LOOSE_GAME:
      return 0;
    default:
      break;
    }
  return 1;
}

/* CartmanPlayer implemention */
CartmanPlayer::CartmanPlayer(Pad * pad, Puck * puck):AIPlayer(pad, puck,
	 "Cartman")
{
  _sdlCartman = loadTga(cartman_tga, NULL);
  _sprUnhappy = new Sprite(cartman_unhappy_spr, NULL);
  _sprLooseGame = new Sprite(cartman_loosegame_spr, NULL);
  _sprUnhappy->setPosition(290, 87);
  _sndKickAss = Audio::instance()->createSound(cartman_kickass_wav, NULL);
  _sndSoab = Audio::instance()->createSound(cartman_soab_wav, NULL);
  _speed = 1.5;
  _hitPower = 2.0;
}

CartmanPlayer::~CartmanPlayer()
{
  SDL_FreeSurface(_sdlCartman);
  delete(_sprUnhappy);
  Audio::instance()->freeSound(_sndKickAss);
  Audio::instance()->freeSound(_sndSoab);
}

void CartmanPlayer::setState(Uint8 state)
{
  _state = state;
  float odds = 0;

  switch (_state)
    {
    case PLAYER_STATE_WIN_POINT:
      odds = (float) rand() / RAND_MAX;
      if (odds > 0.80)
	Audio::instance()->playSound(_sndKickAss);
      break;
    case PLAYER_STATE_LOOSE_GAME:
      Audio::instance()->playSound(_sndSoab);
      break;
    }
}

void CartmanPlayer::blit(void)
{
  static SDL_Rect rect =
    { 320 - _sdlCartman->w / 2, (Sint16) A2 - _sdlCartman->h, 0, 0 };
  Video::instance()->blit(_sdlCartman, &rect);
}

Uint8 CartmanPlayer::reblit(Uint32 time)
{
  switch (_state)
    {
    case PLAYER_STATE_WIN_POINT:
      _state = PLAYER_STATE_IDLE;
      break;
    case PLAYER_STATE_LOOSE_POINT:
      _sprUnhappy->blit();
      if (_sprUnhappy->update(time) == 0)
	{
	  _sprUnhappy->erase();
	  _state = PLAYER_STATE_IDLE;
	}
      break;
    case PLAYER_STATE_LOOSE_GAME:
    case PLAYER_STATE_WIN_GAME:
      _sprLooseGame->blit();
      if (_sprLooseGame->update(time) == 0)
	{
	  _sprLooseGame->erase();
	  _state = PLAYER_STATE_IDLE;
	  return 0;
	}
      break;
    default:
      break;
    }
  return 1;
}
