/*
	TuxPuck - scoreboard.cpp
	Copyright (C) 2001 Jacob Kroon

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

	Jacob Kroon - d00jkr@efd.lth.se
*/

/* includes */
#include "video.h"
#include "scoreboard.h"
#include "global.h"

/* defines */
#define SCOREBOARD_STATE_IDLE	1
#define SCOREBOARD_STATE_ADD_1	2
#define SCOREBOARD_STATE_ADD_2	3
#define ARM_STATE_IDLE		1
#define ARM_STATE_DOWN		2
#define ARM_STATE_UP		3
#define LINE_WIDTH		((Uint32)3)
#define LINE_HEIGHT		((Uint32)22)

/* externals */
extern unsigned char scoreboard_tga[];
extern unsigned char arm_tga[];

/* Scoreboard implemention */
Scoreboard::Scoreboard()
{
  _scoreP1 = _scoreP2 = 0;
  _state = SCOREBOARD_STATE_IDLE;
  _sdlScoreboard = loadTga(scoreboard_tga, NULL);
  _arm = new Arm();
}

Scoreboard::~Scoreboard()
{
  SDL_FreeSurface(_sdlScoreboard);
  delete(_arm);
}

void Scoreboard::addPoint(Uint8 player)
{
  if (player == 1)
    {
      _state = SCOREBOARD_STATE_ADD_1;
    }
  else
    {
      _state = SCOREBOARD_STATE_ADD_2;
    }
}

void Scoreboard::blit(void)
{
  static SDL_Rect rect = { 40, 0, 0, 0 };
  Video::instance()->blit(_sdlScoreboard, &rect);
}

void Scoreboard::reblit(void)
{
  Uint32 i;
  SDL_Rect rect;

  for (i = 0; i < _scoreP1; i++)
    {
      rect.x = 57 + i * 8 + (i / 5 - 1) * 4;
      rect.y = 27;
      rect.w = LINE_WIDTH;
      rect.h = LINE_HEIGHT;
      Video::instance()->
	fillRect(SDL_MapRGB(SDL_GetVideoSurface()->format, 255, 255, 255),
		 &rect);
    }
  for (i = 0; i < _scoreP2; i++)
    {
      rect.x = 57 + i * 8 + (i / 5 - 1) * 4;
      rect.y = 53;
      rect.w = LINE_WIDTH;
      rect.h = LINE_HEIGHT;
      Video::instance()->
	fillRect(SDL_MapRGB(SDL_GetVideoSurface()->format, 255, 255, 255),
		 &rect);
    }
}

void Scoreboard::update(Uint32 time)
{
  switch (_state)
    {
    case SCOREBOARD_STATE_IDLE:
      break;
    case SCOREBOARD_STATE_ADD_1:
      _scoreP1++;
      _state = SCOREBOARD_STATE_IDLE;
      break;
    case SCOREBOARD_STATE_ADD_2:
      _scoreP2++;
      _state = SCOREBOARD_STATE_IDLE;
      break;
    default:
      break;
    }
}

/* Arm implemention */
Arm::Arm()
{
  _state = ARM_STATE_IDLE;
  _x = _y = 0;
  _sdlArm = loadTga(arm_tga, NULL);
}

Arm::~Arm()
{
  SDL_FreeSurface(_sdlArm);
}
